# Changelog

## [1.1.7a1](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/1.1.7a1) (2024-11-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V1.1.6...1.1.7a1)

**Merged pull requests:**

- fix: featured media [\#155](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/155) ([JarbasAl](https://github.com/JarbasAl))

## [V1.1.6](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V1.1.6) (2024-11-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/1.1.6...V1.1.6)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
